]> andersk Git - openssh.git/blobdiff - packet.h
- (djm) Fix a few warnings the above turned up
[openssh.git] / packet.h
index 597fbb1514b4b5fe21862be63120c220b004376d..6430bb0be689f263c543f9635d9f40c9ef033580 100644 (file)
--- a/packet.h
+++ b/packet.h
@@ -11,7 +11,7 @@
  * called by a name other than "ssh" or "Secure Shell".
  */
 
-/* RCSID("$OpenBSD: packet.h,v 1.18 2000/12/19 23:17:57 markus Exp $"); */
+/* RCSID("$OpenBSD: packet.h,v 1.23 2001/05/28 23:58:35 markus Exp $"); */
 
 #ifndef PACKET_H
 #define PACKET_H
@@ -65,13 +65,13 @@ void    packet_start_compression(int level);
  * Informs that the current session is interactive.  Sets IP flags for
  * optimal performance in interactive use.
  */
-void    packet_set_interactive(int interactive, int keepalives);
+void    packet_set_interactive(int interactive);
 
 /* Returns true if the current connection is interactive. */
 int     packet_is_interactive(void);
 
 /* Starts constructing a packet to send. */
-void    packet_start(int type);
+void    packet_start(u_char type);
 
 /* Appends a character to the packet data. */
 void    packet_put_char(int ch);
@@ -178,8 +178,8 @@ extern int max_packet_size;
 int     packet_set_maxsize(int s);
 #define packet_get_maxsize() max_packet_size
 
-/* Stores tty modes from the fd into current packet. */
-void    tty_make_modes(int fd);
+/* Stores tty modes from the fd or tiop into current packet. */
+void    tty_make_modes(int fd, struct termios *tiop);
 
 /* Parses tty modes for the fd from the current packet. */
 void    tty_parse_modes(int fd, int *n_bytes_ptr);
@@ -208,10 +208,13 @@ do { \
 int    packet_connection_is_on_socket(void);
 int    packet_connection_is_ipv4(void);
 
-/* enable SSH2 packet format */
-void   packet_set_ssh2_format(void);
-
 /* returns remaining payload bytes */
 int    packet_remaining(void);
 
+/* append an ignore message */
+void   packet_send_ignore(int nbytes);
+
+/* add an ignore message and make sure size (current+ignore) = n*sumlen */
+void   packet_inject_ignore(int sumlen);
+
 #endif                         /* PACKET_H */
This page took 0.032852 seconds and 4 git commands to generate.